@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
 our $DATE = '2015-11-21'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -132,7 +132,7 @@ sub __gen_table {
                     ",",
                     map {
                         my $cell = $_;
-                        $cell =~ s/"/\\"/g;
+                        $cell =~ s/(["\\])/\\$1/g;
                         qq("$cell");
                     } @$row)."\n";
             } @$data
@@ -224,7 +224,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.07 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2015-11-21.
+This document describes version 0.08 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2015-11-21.
 
 =head1 SYNOPSIS
 
